@@ -36,6 +36,11 @@ impl<M> Envelope<M> {
         &self.message
     }
 
+    #[inline]
+    pub(crate) fn message_kind(&self) -> &MessageKind {
+        &self.kind
+    }
+
     #[inline]
     pub fn sender(&self) -> Addr {
         match &self.kind {
